/*
 * Copyright (C) 2002  Pekka Enberg <Pekka.Enberg@cs.helsinki.fi>
 *
 * Distributed under the terms of the GNU General Public License
 * version 2 or later.
 */
#include "xmlindent.h"
#include <errno.h>
#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

void usage(char * argv[])
{
    printf("%s: [-i <indent level>] [-t] [-c] [-h]\n", argv[0]);
}

int main(int argc, char * argv[])
{
    char * input_filename;
    FILE * input;
    int arg_index;
    bool indent_level_explicitly_defined;

    indent_level_explicitly_defined = false;

    while((arg_index = getopt(argc, argv, "i:cht")) != EOF) {
	switch(arg_index) {
        case 'i':
	    num_indent_chars = atoi(optarg);
	    indent_level_explicitly_defined = true;
	    break;
	case 't':
	    indent_char = '\t';
	    if (!indent_level_explicitly_defined) {
		/* Default indent level for tabs is different.  */
		num_indent_chars = 1;
	    }
	    break;
        case 'c':
	    leave_comments_alone = true;
	    break;
        case 'h':
	    usage(argv);
	    return EXIT_SUCCESS;
        default:
	    usage(argv);
	    return EXIT_FAILURE;
	}
    }

    input_filename = argv[optind];

    if (input_filename != NULL) {
	input = fopen(input_filename, "r");
	if (NULL == input) {
	    error("Could not open '%s': %s.", input_filename, strerror(errno));
	    return EXIT_FAILURE;
	}
    } else {
	input = stdin;
    }
    indent(input, stdout);
    fclose(input);

    return EXIT_SUCCESS;
}
